@@ -110,7 +110,17 @@ public:
 	vector<MetviewIcon >::const_iterator iconsEnd() { return icons_.end(); }
 	void  icon(const string& iconname, const string& iconclass,const string& iconid) 
 			{  icons_.push_back(MetviewIcon(iconname, iconclass,iconid)); }
-	
+	void  icon(const MetviewIcon& icon)
+			{  MetviewIcon add; 
+				add.icon(icon); 
+				icons_.push_back(add); 
+				visibility_ = icon.visibility(); 
+				transparency_ = icon.transparency();
+//F20161116				zindex_ = icon.zindex();  
+				id_ = icon.id(); 
+				name_ = icon.name();
+			}
+
 	//void setInfo(const string& name, const string& value) { information_[name]=value; }
 	//virtual const map<string, string>& getInfos(bool =false) const { return information_; }
 
@@ -266,13 +276,24 @@ public:
 	TextLayer() {}
 	~TextLayer() {}
 	void getReady() const;
+    void getReady(int i) const { Layer::getReady(i); }
 	void execute(const BaseDriver&) const;
 	void execute(int, const BaseDriver&) const;
 	void getInfo(int, const BaseDriver&) const;
 	void collectText(vector<TextVisitor*>&, LegendVisitor*); // update the text informations!
 };
 
-
+class LegendLayer : public StepLayer
+{
+public:
+	LegendLayer() {}
+	~LegendLayer() {}
+	void getReady() const;
+	void execute(const BaseDriver&) const;
+	void execute(int, const BaseDriver&) const;
+	void getInfo(int, const BaseDriver&) const;
+	
+};
 /*
  * A SceneLayer is attach to a SceneNode...
  * It contains the list of layers needed to perform a plot.
@@ -294,8 +315,9 @@ public:
 
 	Layer*  findLayer(Layer*,int) const; 
 	
-	void legend(LegendVisitor* legend) { legend_ = legend; }
-	void text(TextVisitor* text) { textVisitors_.push_back(text); }
+	void legend(LegendVisitor* legend);
+	void text(TextVisitor* text);
+
 	
 	void getReady(int) const;
 
@@ -335,6 +357,7 @@ protected:
 	mutable std::set<LayoutVisitor*> visitors_;
 	mutable  vector<TextVisitor*> textVisitors_;
 	mutable TextLayer textHandler_;
+	mutable LegendLayer legendHandler_;
 
 	mutable LegendVisitor* legend_;
 	MagicsMode mode_;
