@@ -70,7 +70,14 @@ public:
 	string from()  { return tostring(from_); }
 	string to() { return tostring(to_); }
 	 
-	void userText(const string& text) { userText_ = text; }
+	void userText(const string& text, const string& automatic) 
+		{ if ( userText_.size() )
+			return;
+		   userText_ = text; 
+
+		   automatic_ = magCompare(automatic, "automatic_text_only"); 
+		  
+		}
 	const string& userText() { return userText_; }
 	const string& units() { return units_; }
 	void units(const string& units) { units_ = units; }
@@ -98,11 +105,14 @@ public:
 	void  mean(double mean)  { meanValue_ = mean; meanSet_ = true; }
 	void  histogramInformation(HistogramLegendMethod* histo) {histogram_ = histo;}
 	void  borderColour(const Colour& colour)  {  borderColour_ = colour; }
-
+	void  minText(const string& text)  {  minText_ = text; label_ = text; }
+	void  maxText(const string& text)  {  maxText_ = text; label_ = text; }
+	
 protected:
 	bool last_;
 	bool first_;
 	bool text_;
+	bool automatic_; // True if the tlegend text is generated automaticaly from the value.
 	mutable string label_;
     bool fromto_;
     Colour borderColour_;
@@ -111,8 +121,12 @@ protected:
 
     string userText_;
     string units_;
+	string minText_;
+	string maxText_;
+
 	double from_;
 	double to_;
+
 	string format_;
 	MagFont font_;
 	double angle_;
@@ -218,6 +232,7 @@ public:
 		LineEntry(label, line) { }
 	bool needContinuousText(Text&) { return true;  }
 	void rowBox(const PaperPoint&, BasicGraphicsObjectContainer&);
+	void columnBox(const PaperPoint&, BasicGraphicsObjectContainer&);
 
 	~RainbowEntry();
 };
@@ -388,7 +403,7 @@ protected:
     string both(const string& automatic, const string& user) 
         { return automatic + " " + user; } 
     string user_only(const string&, const string& user)
-         { return  user; } 
+         { if ( user.empty() ) return " "; return user; } 
     string automatic_only(const string& automatic, const string&) 
         { return automatic; }
     
