@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 #ifndef MagicsException_H
 #define MagicsException_H
@@ -31,18 +23,18 @@ class MagicsException : public exception
         if (std::getenv("MAGICS_ABORT_EXCEPTION")) {
             std::abort();
         }
-    } 
+    }
 
     MagicsException() : what_("") {
         if (std::getenv("MAGICS_ABORT_EXCEPTION")) {
             std::abort();
         }
-    } 
+    }
 
 	virtual const char *what() const throw() {  return what_.c_str(); }
 	virtual ~MagicsException() throw() {}
  protected:
-    virtual void print(ostream& out) const 
+    virtual void print(ostream& out) const
     {
         out << what_;
     }
@@ -59,35 +51,35 @@ class NoSuchFileException : public MagicsException
 public:
 	 NoSuchFileException( const string& file ):
 		MagicsException("No Such File: " +  file){}
-};     
+};
 
 class NoWritePermissionException : public MagicsException
 {
 public:
 	 NoWritePermissionException( const string& file ):
 		MagicsException("No write permission to write file: " +  file){}
-};     
-    
+};
+
 class NotYetImplemented : public MagicsException
 {
 public:
 	 NotYetImplemented(const string& type, const string& method ):
 		MagicsException( type + " " + method  + " : not yet implemented... "){}
-};         
+};
 
 class MethodNotYetImplemented : public NotYetImplemented
 {
 public:
 	 MethodNotYetImplemented(const string& method):
-		NotYetImplemented("Method",  method) {}  
-};    
-     
+		NotYetImplemented("Method",  method) {}
+};
+
 class ParameterNotYetImplemented : public NotYetImplemented
 {
 public:
 	 ParameterNotYetImplemented(const string& param):
 		NotYetImplemented("Parameter", param){}
-}; 
+};
 
 class AssertionFailed : public MagicsException {
 public:
@@ -115,7 +107,11 @@ public:
 
 #ifndef ASSERT
 #define ASSERT(a)  Assert(!(a),#a,__LINE__,__FILE__,__FUNCTION__)
-#endif 
+#endif
+
+#ifndef NOTIMP
+#define NOTIMP     throw MethodNotYetImplemented(__FUNCTION__)
+#endif
 
 #endif
 // EXCEPTION_H_
