@@ -79,17 +79,17 @@ public:
 	}
 
 	void geosinit(const Proj4Projection& from) {
-		//cout <<  from.vertical_longitude_ << endl;
+		
 		minlon_ = from.vertical_longitude_ - 80;
 		maxlon_ = from.vertical_longitude_ + 80;
 		minlat_ = -80;
 		maxlat_ = 80;
-		//cout <<  minlon_ << "   " << maxlon_ << endl;
+		
 		ostringstream def;
 		def << "+proj=geos +h=42164000 +ellps=WGS84 +lon_0=" << from.vertical_longitude_;
 
 		definition_ = def.str();
-		//cout << definition_ << endl;
+		
 	}
 
 
@@ -277,11 +277,60 @@ void Proj4Projection::init()
 
 void Proj4Projection::full()
 {
+	if ( projection_->method_ == "simple" ) {
+
+		if ( max_longitude_ != 180. ) {
+			if ( max_latitude_ == 90 )	
+				max_latitude_ = projection_->maxlat_;
+			if ( min_latitude_ == -90 )	
+				min_latitude_ = projection_->minlat_;
+			corners();
+			return;
+		}
+		if ( max_longitude_ == 180. ) {
+			projection_->maxlon_ = 180.;
+			if ( max_latitude_ == 90 )	
+				max_latitude_ = projection_->maxlat_;
+			if ( min_latitude_ == -90 )	
+				min_latitude_ = projection_->minlat_;
+			corners();
+			return;
+		}
+		
+		if ( min_longitude_ != -180 ) {
+
+			// set projection default ! 
+			if ( max_latitude_ == 90 )	
+				max_latitude_ = projection_->maxlat_;
+			if ( min_latitude_ == -90 )	
+				min_latitude_ = projection_->minlat_;
+			corners();
+		}
+		
+		if ( min_latitude_ != -90 ) {
+			
+			if ( max_latitude_ == 90 )	
+				max_latitude_ = projection_->maxlat_;
+			
+			corners();
+			return;
+		}
+		if ( max_latitude_ != 90 ) {
+			if ( min_longitude_ == -180 )
+				min_longitude_ = projection_->minlon_;
+			if ( min_latitude_ == -90 )	
+				min_latitude_ = projection_->minlat_;			
+			corners();
+			return;
+		}
+	
+	}
+	
 }
 
 void Proj4Projection::corners()
 {
-	// we have to update the PVBounding box!
+	// we have to update the PCBounding box!
 		min_pcx_ = min_longitude_;
 		min_pcy_ = min_latitude_;
 		max_pcx_ = max_longitude_;
@@ -328,7 +377,11 @@ PaperPoint Proj4Projection::operator()(const UserPoint& point)  const
     int error = pj_transform(from_, to_, 1, 1, &x, &y, NULL);
     if ( error ) {
 		MagLog::debug() << pj_strerrno(error) << " for " << point << endl;
-		return PaperPoint(-1000000, -10000000);
+//		NON Valeurs trop faibles en EPSG:3857 par exemple !  --> Transformation::in(pp) == True !
+//		-> Avec ces valeurs, si grille globale, les barbules des poles sont tracées dans l'atlantique sud
+//		en formant une couronne centrée vers( 9°W, 66°35S)
+//		return PaperPoint(-1000000, -10000000);   .// En plus il manque 1 zero !
+		return PaperPoint(-1e10, -1e10);    // Devrait suffire pour que Transformation::in(pp) == False qqsoient from_ et to_
 	}
 	
 	return PaperPoint(x, y, point.value_, point.missing(), point.border(), 0, point.name());
@@ -361,6 +414,19 @@ void Proj4Projection::setNewPCBox(double minx, double miny, double maxx, double
 
 void Proj4Projection::revert(const PaperPoint& xy, UserPoint& point)  const
 {
+	static bool first = true;
+	if ( first ) {
+		
+		const_cast<Proj4Projection*>(this)->init();
+		first = false;
+	}
+	if ( PCEnveloppe_->within(xy) == false ) {
+				  point = UserPoint(-1000, -1000);
+				  
+			 return;
+	}
+
+
 	double x = xy.x();
 	double y = xy.y();
 
@@ -399,6 +465,7 @@ void Proj4Projection::add(double lon, double lat)
 	int error =  pj_transform(from_, to_, 1, 1, &x, &y, NULL );
 	userEnveloppe_->push_back(PaperPoint(lon, lat));
 	PCEnveloppe_->push_back(PaperPoint(x, y));
+	
 	if ( x < min_pcx_ )  min_pcx_ = x;
 	if ( y < min_pcy_ )  min_pcy_ = y;
 	if ( x > max_pcx_ )  max_pcx_ = x;
@@ -549,7 +616,6 @@ void Proj4Projection::boundingBox(double& xmin, double& ymin, double& xmax, doub
 	xmin = gridMinLon_-5;
 	ymax = gridMaxLat_;
 	xmax = gridMaxLon_+5;
-	//cout << "Bounding box ->" << xmin << " " << xmax << endl;
 }
 
 double Proj4Projection::getMinX()  const
@@ -624,7 +690,7 @@ void Proj4Projection::gridLongitudes(const GridPlotting& grid)  const
 
 	grid.add(boundaries);
 
-	//return;
+	
 	vector<double> longitudes = grid.longitudes();
 
 
@@ -644,7 +710,10 @@ void Proj4Projection::gridLongitudes(const GridPlotting& grid)  const
 				if ( userEnveloppe_->within(p) )
 					poly.push_back((*this)(UserPoint(*lon,lat)));
 			}
-			grid.add(poly);
+			if ( *lon == gridMinLon_ || *lon == gridMaxLon_) 
+				grid.addFrame(poly);
+			else 
+				grid.add(poly);
 		}
 }
 
@@ -665,7 +734,11 @@ void Proj4Projection::gridLatitudes(const GridPlotting& grid)  const
 			if ( userEnveloppe_->within(p) )
 				poly.push_back((*this)(UserPoint(lon,*lat)));
 		}
-		grid.add(poly);
+		if ( *lat == gridMinLat_ || *lat == gridMaxLat_) 
+				grid.addFrame(poly);
+			else 
+				grid.add(poly);
+		
 	}
 }
 
@@ -677,8 +750,8 @@ void Proj4Projection::labels(const LabelPlotting& label, DrawingVisitor& visitor
 	pro4_longitudes.push_back(0);
 	pro4_longitudes.push_back(90);
 	pro4_longitudes.push_back(-90);
-	pro4_longitudes.push_back(180);
-	pro4_longitudes.push_back(-180);
+	//pro4_longitudes.push_back(180);
+	//pro4_longitudes.push_back(-180);
 	const vector<double>& longitudes = label.longitudes();
 	const vector<double>& latitudes = label.latitudes();
 	for (vector<double>::const_iterator lat = latitudes.begin(); lat != latitudes.end(); ++lat)
@@ -885,7 +958,7 @@ void Proj4Projection::horizontalLabels(const LabelPlotting& label, double y, dou
 
 void Proj4Projection::labels(const LabelPlotting& label, TopAxisVisitor& visitor)  const
 {
-	if ( true ) {
+	if ( projection_->method_ == "simple" ) {
 		const vector<double>& longitudes = label.longitudes();
 		const double lat = min_latitude_ + (max_latitude_-min_latitude_)*.2;
 		for (unsigned int lon = 0; lon < longitudes.size(); lon++ )
@@ -932,11 +1005,12 @@ void Proj4Projection::reprojectComponents(double& x, double& y, pair<double, dou
 
 void myprint(double x, double y, bool next = false) 
 {
-	cout << "[" << x << ", " << y << "]";
+	
+	MagLog::dev() << "[" << x << ", " << y << "]";
 	if ( next )
-		cout << "--->";
+		MagLog::dev() << "--->";
 	else 
-		cout << endl;
+		MagLog::dev() << endl;
 }
 
 void Proj4Projection::reprojectSpeedDirection(const PaperPoint& point, pair<double, double>& wind) const
