@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Symbol.cc
     \brief Implementation of Symbol graphics class (template).
@@ -91,6 +83,8 @@ Symbol* SymbolProperties::symbol(const string& type) const
 
 	const unsigned text_size = text_.size();
 	
+	
+
 	if ( magCompare(type, "marker")  )	{
 		if ( image_  ) {
 			ImageSymbol* img =  new ImageSymbol(image_path_, image_format_);
@@ -138,6 +132,12 @@ Symbol* SymbolProperties::symbol(const string& type) const
 			text->font(font_);
 			text->text(text_);
 			text->blanking(blanking_);
+			
+			symbol->setColour(Colour("none"));
+			symbol->setSymbol(marker_);
+			symbol->setHeight(0.0);
+
+			return symbol;
 		}
 	}
 	if ( magCompare(type, "number") )
