@@ -21,7 +21,7 @@
 
 #include "NetcdfGeoMatrixInterpretor.h"
 #include "Factory.h"
-#include "Netcdf.h"
+#include "NetcdfData.h"
 #include <limits>
 #include "Layer.h"
 
@@ -36,13 +36,14 @@ NetcdfGeoMatrixInterpretor::~NetcdfGeoMatrixInterpretor()
 
 
 
-bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
+bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** matrix)
 {
-	if ( *data ) return false;
+	if ( *matrix ) return false;
 	
 	Netcdf netcdf(path_, dimension_method_);
 
-	string proj4 = netcdf.getAttribute("projection", "");
+
+	string proj4 = netcdf.getAttribute("projection", string(""));
 
 	if ( proj4.empty() ) {
 		matrix_ = new Matrix();
@@ -52,27 +53,22 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
 		
 		matrix_ = new Proj4Matrix(proj4);
 	}
-	*data = matrix_;
+	*matrix = matrix_;
 
-	double missing_value = netcdf.getMissing(field_, missing_attribute_);
+	
 
 	// get the data ...
 	try
 	{
+		double missing_value = netcdf.getMissing(field_, missing_attribute_);
 		map<string, string> first, last;
 		setDimensions(dimension_, first, last);
 		vector<double> inlon, outlon;
 		vector<double> inlat, outlat;
-
 		
 		netcdf.get(longitude_, matrix_->columnsAxis(), first, last);
 		netcdf.get(latitude_, matrix_->rowsAxis(), first, last);
 	
-
-		
-
-
-
 		matrix_->missing(missing_value);
 
 		if  ( magCompare(primary_index_, "latitude") ) {			
@@ -86,25 +82,22 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
 			     }
 		}
 		else {
+			Timer timer("CREATE matrix", "prepare");
 			vector<double> data;	
 			netcdf.get(field_, data, first, last);
-
 			matrix_->reserve(data.size());
+			int i = 0;
 			fill(matrix_->begin(), matrix_->end(), missing_value);
 			for (vector<double>::iterator d = data.begin(); d != data.end(); ++d ) 
 			{
-
-
 				if ( !std::isnan(*d) ) {
 					matrix_->push_back(*d);
-				}
-				else 
 					
-					matrix_->push_back(missing_value);
-				
+				}
+				i++;			
 			}
 		}
-
+		
 		matrix_->multiply(scaling_);
 		matrix_->plus(offset_);
 	    matrix_->setMapsAxis();
@@ -112,6 +105,8 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
 	catch (MagicsException& e)
 	{
 		MagLog::error() << e << "\n";
+		delete matrix_;
+		matrix_ = NULL;
 		return false;
 	}
 	return true;
@@ -124,7 +119,7 @@ void NetcdfGeoMatrixInterpretor::print(ostream& out)  const
 {
 	out << "NetcdfGeoMatrixInterpretor[";
 	NetcdfInterpretor::print(out);
-	NetcdfGeoMatrixInterpretorAttributes::print(out);
+	
 	out << "]";
 }
 
@@ -160,7 +155,7 @@ void NetcdfGeoMatrixInterpretor::visit(Transformation& transformation) {
 bool NetcdfGeoMatrixInterpretor::interpretAsPoints(PointsList& list)
 {
 	Netcdf netcdf(path_, dimension_method_);
-	string proj4 = netcdf.getAttribute("projection", "");
+	string proj4 = netcdf.getAttribute("projection", string(""));
 
 	if ( !proj4.empty() ) {
 		proj4_ = pj_init_plus(proj4.c_str());
@@ -181,8 +176,8 @@ bool NetcdfGeoMatrixInterpretor::interpretAsPoints(PointsList& list)
 		netcdf.get(latitude_, latitudes, first, last);
 		unsigned int val = 0;
 		
-		for (unsigned int  lat  =0 ; lat < latitudes.size(); lat+=latitude_sample_) {
-			for ( unsigned int lon = 0; lon < longitudes.size(); lon+=longitude_sample_) {
+		for (unsigned int  lat  =0 ; lat < latitudes.size(); lat++) {
+			for ( unsigned int lon = 0; lon < longitudes.size(); lon++) {
 				val = (lat* longitudes.size() + lon);
 				if ( val >= values.size() ) return true;
 				if ( values[val] < suppress_below_ ) continue;
@@ -303,3 +298,31 @@ void NetcdfGeoMatrixInterpretor::customisedPoints(const Transformation& transfor
 			MagLog::error() << e << "\n";
 		}
 }
+
+
+NetcdfInterpretor* NetcdfGeoMatrixInterpretor::guess(const NetcdfInterpretor& from)
+{
+	if ( from.field_.empty() &&  (from.x_component_.empty() || from.y_component_.empty() ) ) 
+		return 0;
+	
+	Netcdf netcdf(from.path_, from.dimension_method_);
+	
+	string variable = from.field_;
+	if ( variable.empty() ) 
+		variable = from.x_component_;
+	string latitude = netcdf.detect(variable, "latitude");
+	string longitude = netcdf.detect(variable, "longitude");
+
+	if ( latitude.size() && longitude.size() ) {
+		NetcdfGeoMatrixInterpretor* interpretor = new NetcdfGeoMatrixInterpretor();
+		
+		interpretor->NetcdfInterpretor::copy(from);
+		interpretor->latitude_ = latitude;
+		interpretor->longitude_ = longitude;
+		interpretor->time_variable_ = netcdf.detect(variable, "time");
+		interpretor->level_variable_ = netcdf.detect(variable, "level");
+		interpretor->number_variable_ = netcdf.detect(variable, "number");
+		return interpretor;
+	}
+	return 0;
+}
