@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file NetcdfGeopointsInterpretor.cc
     \brief Implementation of the Template class NetcdfGeopointsInterpretor.
@@ -30,7 +22,7 @@
 #include "NetcdfGeopointsInterpretor.h"
 #include "TextVisitor.h"
 #include "Factory.h"
-#include "Netcdf.h"
+#include "NetcdfData.h"
 #include <limits>
 #include "Layer.h"
 #include "SciMethods.h"
@@ -81,8 +73,8 @@ bool NetcdfGeopointsInterpretor::interpretAsPoints(PointsList& list, const Trans
 		
 		//If the lat-lon units is specified as "radians" convert lat-lon 
 		//to degrees. By default the units are sipposed to be "degrees"
-		const char *units = 0;
-		if ( magCompare(netcdf.getVariableAttribute(latitude_,"units",units), "radians") )
+		string units;
+		if ( magCompare(netcdf.getVariableAttribute(latitude_,"units", units), string("radians")) )
 		{			
 			while ( lat!= latitudes.end()) {
 			  *lat=DEG(*lat);
@@ -138,7 +130,7 @@ bool NetcdfGeopointsInterpretor::interpretAsPoints(PointsList& list)
 		
 		//If the lat-lon units is specified as "radians" convert lat-lon 
 		//to degrees. By default the units are sipposed to be "degrees"
-		const char *units = 0;
+		string units;
 		if ( magCompare(netcdf.getVariableAttribute(latitude_,"units",units), "radians") )
 		{
 			while ( lat!= latitudes.end()) {
@@ -465,8 +457,7 @@ void NetcdfXYpointsInterpretor::visit(MetaDataCollector& mdc)
 	map<string, NetAttribute>::iterator attrIt=attrs.find("_VIEW");
 	if( attrIt !=  attrs.end())
 	{  
-	  	const char* val;	  
-	  	attrIt->second.get(val);
+	  	const char* val =0; // = attrIt->second.get();
 	  	string str;
 	  	if(val) str=string(val);
 	  
