@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \defgroup drivers Output drivers
 
@@ -406,6 +398,7 @@ protected:
 
 	bool    disabled_;
 	bool    alphaEnabled_;
+	mutable int       applyGaussianBlur_;
 	mutable vSymbols  sym_;
 
 	virtual MAGICS_NO_EXPORT void setNewLineWidth(const MFloat w) const {currentLineWidth_ = w;}
@@ -453,8 +446,6 @@ protected:
 	mutable std::map<string, magFont, RuntimeStringCompare> FontMap_;
 	typedef std::map<string, magFont, RuntimeStringCompare>::const_iterator fontMapIter;
 
-	void terminate() const {exit(1);}
-
 	void readFonts() const;
 	void relieveFonts() const {FontMap_.clear();}
 
