@@ -1,22 +1,12 @@
-/******************************** LICENSE ********************************
-
-
-  Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
- 
-  Licensed under the Apache License, Version 2.0 (the "License"); 
-  you may not use this file except in compliance with the License. 
-  You may obtain a copy of the License at 
- 
-     http://www.apache.org/licenses/LICENSE-2.0
- 
-  Unless required by applicable law or agreed to in writing, software 
-  distributed under the License is distributed on an "AS IS" BASIS, 
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-  See the License for the specific language governing permissions and 
-  limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file BaseDriverSymbols.h
     \brief Implementation of Symbol methods of driver base class.
@@ -123,6 +113,7 @@ MAGICS_NO_EXPORT void BaseDriver::renderTextSymbols(const TextSymbol& symbol) co
 	//Loop for all positions
 	for(int i=0;i< nPos ;i++)
 	{
+	  if(!symbol.text().at(i).empty()) {
 		Text text;
 		text.setJustification(MCENTRE);
 		text.setVerticalAlign(MHALF);
@@ -162,6 +153,7 @@ MAGICS_NO_EXPORT void BaseDriver::renderTextSymbols(const TextSymbol& symbol) co
 		text.setAngle(0.);
 		text.addText(symbol.text().at(i), symbol.font()); //75 dpi
 		renderText(text);
+	  }
 	}
 	renderSymbols(symbol);
 }
@@ -208,6 +200,7 @@ MAGICS_NO_EXPORT void BaseDriver::renderTextItem(const TextItem& textItem, const
 MAGICS_NO_EXPORT void BaseDriver::renderFlagItem(const FlagItem& flagItem, const ComplexSymbol& owner) const
 {
 	Flag flag;
+	flag.setThickness(flagItem.thickness());
 	flag.setLength(flagItem.length());
 	flag.setOriginMarker(flagItem.getOriginMarker());
 	flag.setOriginHeight(flagItem.getOriginHeight());           // NOT flagItem.getOriginHeight() !!!
