@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -72,16 +72,13 @@ Display *dpy;
 
 #define FONT_SCALE 25*.7  //! \todo clean-up!!!
 
-extern "C"{
-#include "libimagequant/pngquant.h"
-}
 
 using namespace magics;
 
 /*!
   \brief Constructor
 */
-CairoDriver::CairoDriver() : filename_(""), offsetX_(0), offsetY_(0), backend_("PDF")
+CairoDriver::CairoDriver() : offsetX_(0), offsetY_(0), backend_("PDF")
 {
         cr_ = 0;
 }
@@ -158,8 +155,8 @@ void CairoDriver::setupNewSurface() const
 	else if(magCompare(backend_,"pdf"))
 	{
 #if CAIRO_HAS_PDF_SURFACE
-	    filename_ = getFileName("pdf");
-	    surface_ = cairo_pdf_surface_create(filename_.c_str(), dimensionXglobal_, dimensionYglobal_);
+	    fileName_ = getFileName("pdf");
+	    surface_ = cairo_pdf_surface_create(fileName_.c_str(), dimensionXglobal_, dimensionYglobal_);
 #else
 	    MagLog::error() << "CairoDriver: PDF output NOT supported! Enable PDF support in your Cairo installation." << std::endl;
 #endif
@@ -167,10 +164,10 @@ void CairoDriver::setupNewSurface() const
 	else if(magCompare(backend_,"ps"))
 	{
 #if CAIRO_HAS_PS_SURFACE
-        filename_ = getFileName("ps"); 
+        fileName_ = getFileName("ps");
         const int dimensionXglobal = static_cast<int>(getXDeviceLength()*72/2.54);
         const int dimensionYglobal = static_cast<int>(getYDeviceLength()*72/2.54);
-        surface_ = cairo_ps_surface_create(filename_.c_str(), dimensionXglobal,dimensionYglobal);
+        surface_ = cairo_ps_surface_create(fileName_.c_str(), dimensionXglobal,dimensionYglobal);
 #else
 	    MagLog::error() << "CairoDriver: PS output NOT supported! Enable PS support in your Cairo installation." << std::endl;
 #endif
@@ -178,22 +175,22 @@ void CairoDriver::setupNewSurface() const
 	else if(magCompare(backend_,"eps"))
 	{
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 5, 2)
-	    filename_ = getFileName("eps");
-	    surface_ = cairo_ps_surface_create(filename_.c_str(), dimensionXglobal_, dimensionYglobal_);
+	    fileName_ = getFileName("eps");
+	    surface_ = cairo_ps_surface_create(fileName_.c_str(), dimensionXglobal_, dimensionYglobal_);
 	    cairo_ps_surface_set_eps (surface_,true);
 #else
 	    MagLog::error() << "CairoDriver: EPS output NOT supported! You need at least version Cairo 1.5.2.\n"
 	                 << "PostScript is generated instead." << std::endl;
-	    filename_ = getFileName("ps");
-	    surface_ = cairo_ps_surface_create(filename_.c_str(), dimensionXglobal_, dimensionYglobal_);
+	    fileName_ = getFileName("ps");
+	    surface_ = cairo_ps_surface_create(fileName_.c_str(), dimensionXglobal_, dimensionYglobal_);
 #endif
 	}
 	else if(magCompare(backend_,"svg"))
 	{
 #if CAIRO_HAS_SVG_SURFACE
-	    filename_ = getFileName("svg",currentPage_+1);
+	    fileName_ = getFileName("svg",currentPage_+1);
 
-	    surface_ = cairo_svg_surface_create (filename_.c_str(), dimensionXglobal_, dimensionYglobal_);
+	    surface_ = cairo_svg_surface_create (fileName_.c_str(), dimensionXglobal_, dimensionYglobal_);
 //	    cairo_svg_surface_restrict_to_version (surface_, CAIRO_SVG_VERSION_1_2);
 #else
 	    MagLog::error() << "CairoDriver: SVG output NOT supported! Enable SVG support in your Cairo installation." << std::endl;
@@ -267,8 +264,8 @@ void CairoDriver::setupNewSurface() const
 void CairoDriver::close()
 {
 	currentPage_ = 0;
-	if(magCompare(backend_,"pdf") && !filename_.empty()) printOutputName("CAIRO pdf "+filename_);
-	if(magCompare(backend_,"ps") && !filename_.empty()) printOutputName("CAIRO ps "+filename_);
+	if(magCompare(backend_,"pdf") && !fileName_.empty()) printOutputName("CAIRO pdf "+fileName_);
+	if(magCompare(backend_,"ps") && !fileName_.empty()) printOutputName("CAIRO ps "+fileName_);
 
 	if (!context_) {
 		cairo_surface_destroy (surface_);
@@ -310,8 +307,8 @@ MAGICS_NO_EXPORT void CairoDriver::startPage() const
 			cairo_destroy (cr_);
 			cairo_surface_destroy (surface_);
 
-			filename_ = getFileName("svg",currentPage_+1);
-			surface_ = cairo_svg_surface_create(filename_.c_str(), dimensionXglobal_, dimensionYglobal_);
+			fileName_ = getFileName("svg",currentPage_+1);
+			surface_ = cairo_svg_surface_create(fileName_.c_str(), dimensionXglobal_, dimensionYglobal_);
 			cr_ = cairo_create (surface_);
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 4, 0)
 			cairo_svg_surface_restrict_to_version (surface_, CAIRO_SVG_VERSION_1_1);
@@ -324,8 +321,8 @@ MAGICS_NO_EXPORT void CairoDriver::startPage() const
 			cairo_destroy (cr_);
 			cairo_surface_destroy (surface_);
 
-			filename_ = getFileName("eps",currentPage_+1);
-			surface_ = cairo_ps_surface_create(filename_.c_str(), dimensionXglobal_, dimensionYglobal_);
+			fileName_ = getFileName("eps",currentPage_+1);
+			surface_ = cairo_ps_surface_create(fileName_.c_str(), dimensionXglobal_, dimensionYglobal_);
 			cairo_ps_surface_set_eps (surface_,true);
 			cr_ = cairo_create (surface_);
 #endif
@@ -355,34 +352,34 @@ MAGICS_NO_EXPORT void CairoDriver::endPage() const
 
 	if(magCompare(backend_,"eps"))
 	{
-		if(!filename_.empty()) printOutputName("CAIRO eps "+filename_);
+		if(!fileName_.empty()) printOutputName("CAIRO eps "+fileName_);
 	}
 	else if(magCompare(backend_,"svg"))
 	{
-		if(!filename_.empty()) printOutputName("CAIRO svg "+filename_);
+		if(!fileName_.empty()) printOutputName("CAIRO svg "+fileName_);
 	}
 	else if (magCompare(backend_,"png") )
 	{
 		Timer timer("cairo", "write png");
-		filename_ = getFileName("png" ,currentPage_);
+		fileName_ = getFileName("png" ,currentPage_);
 		if(magCompare(palette_,"on"))
 		{
 		   if(!write_8bit_png())
 		   {
 		     MagLog::warning() << "CairoDriver::renderPNG > palletted PNG failed! Generate 24 bit one ..." << endl;
-		     cairo_surface_write_to_png(surface_, filename_.c_str());
+		     cairo_surface_write_to_png(surface_, fileName_.c_str());
 		   }
 		}
 		else
 		{
-		   cairo_surface_write_to_png(surface_, filename_.c_str());
+		   cairo_surface_write_to_png(surface_, fileName_.c_str());
 		}
-		if(!filename_.empty()) printOutputName("CAIRO png "+filename_);
+		if(!fileName_.empty()) printOutputName("CAIRO png "+fileName_);
 	}
 	else if (magCompare(backend_,"geotiff") )
 	{
 #ifdef HAVE_GEOTIFF
-		filename_ = getFileName("tif" ,currentPage_);
+		fileName_ = getFileName("tif" ,currentPage_);
 		write_tiff();
 #else
 		MagLog::error() << "CairoDriver: GEOTIFF not enabled!"<< std::endl;
@@ -400,7 +397,7 @@ void CairoDriver::newLayer(Layer&) const
 
 void CairoDriver::closeLayer(Layer&) const
 {
-    if(applyGaussianBlur_ > 0) 
+    if(applyGaussianBlur_ > 0)
     {
         blur_image_surface(surface_,50);
     }
@@ -432,16 +429,16 @@ MAGICS_NO_EXPORT void CairoDriver::write_tiff() const
     int          height = cairo_image_surface_get_height(surface_);
     const int    stride = cairo_image_surface_get_stride(surface_);
 
-    TIFF *tif = TIFFOpen(filename_.c_str(), "w");
+    TIFF *tif = TIFFOpen(fileName_.c_str(), "w");
     if (!tif) {
-        MagLog::warning() << "CairoDriver: Unable to open TIFF file "<<filename_<< std::endl;
+        MagLog::warning() << "CairoDriver: Unable to open TIFF file "<<fileName_<< std::endl;
         return;
     }
-    
+
     GTIF *gtif = GTIFNew(tif);
     if (!gtif)
     {
-        MagLog::warning() << "CairoDriver: Unable to open GeoTIFF file "<<filename_<< std::endl;
+        MagLog::warning() << "CairoDriver: Unable to open GeoTIFF file "<<fileName_<< std::endl;
         return;
     }
 
@@ -510,15 +507,16 @@ MAGICS_NO_EXPORT void CairoDriver::write_tiff() const
 
 MAGICS_NO_EXPORT bool CairoDriver::write_8bit_png() const
 {
+/*
     cairo_surface_flush (surface_);
     unsigned char *data = cairo_image_surface_get_data(surface_);
     const int     width = cairo_image_surface_get_width(surface_);
     const int    height = cairo_image_surface_get_height(surface_);
-  
+
     struct pngquant_options options_ = { };
     options_.liq = liq_attr_create();
     struct pngquant_options *options = &options_;
-    //    pngquant_file(filename_.c_str(), filename.c_str(), &options);
+    //    pngquant_file(fileName_.c_str(), filename.c_str(), &options);
 
     pngquant_error  retval             = SUCCESS;
     liq_image*      input_image        = NULL;
@@ -534,12 +532,12 @@ MAGICS_NO_EXPORT bool CairoDriver::write_8bit_png() const
 	data2[h*4*width+w+3] = data[h*4*width+w+3];  // a
       }
     }
- 
+
     input_image = liq_image_create_rgba(options->liq, data2, width, height, 0);
     if (!input_image) {
         //return OUT_OF_MEMORY_ERROR;
     }
-    
+
     int quality_percent = 90; // quality on 0-100 scale, updated upon successful remap
     png8_image output_image = {};
 
@@ -571,24 +569,25 @@ MAGICS_NO_EXPORT bool CairoDriver::write_8bit_png() const
     if (SUCCESS == retval) {
         output_image.fast_compression  = false; //  (fast_compression ? Z_BEST_SPEED : Z_BEST_COMPRESSION);
 
-        retval = write_image(&output_image, NULL, filename_.c_str(), options);
+        retval = write_image(&output_image, NULL, fileName_.c_str(), options);
     }
 
     liq_image_destroy(input_image);
     rwpng_free_image8(&output_image);
 
     if (SUCCESS == retval) return true;
+*/
     return false;
 }
 
-/*  
+/*
 MAGICS_NO_EXPORT void CairoDriver::write_8bit_png() const
 {
-    const string filename = filename_ +"_8bit";    
+    const string filename = fileName_ +"_8bit";
     FILE * fp = fopen (filename.c_str(), "wb");
     if (! fp) {
         MagLog::error() << "CairoDriver: Unable to open 8 bit PNG file "<<filename<< std::endl;
-        return;        
+        return;
     }
 
     cairo_surface_flush (surface_);
@@ -604,7 +603,7 @@ MAGICS_NO_EXPORT void CairoDriver::write_8bit_png() const
     	MagLog::error() << "CairoDriver: Unable to create WRITE struct for 8 bit PNG file "<<filename<< std::endl;
         return;
     }
- 
+
     png_infop info_ptr  = png_create_info_struct (png_ptr);
     if(!png_ptr)
     {
@@ -612,7 +611,7 @@ MAGICS_NO_EXPORT void CairoDriver::write_8bit_png() const
         return;
     }
 //    setjmp (png_jmpbuf (png_ptr));
-    
+
     // Set image attributes
     png_set_IHDR (png_ptr,
                   info_ptr,
@@ -623,21 +622,21 @@ MAGICS_NO_EXPORT void CairoDriver::write_8bit_png() const
                   PNG_INTERLACE_NONE,
                   PNG_COMPRESSION_TYPE_DEFAULT,
                   PNG_FILTER_TYPE_DEFAULT);
-    
+
     // Initialize rows of PNG.
     png_bytep *row_pointers = (png_bytep*) malloc(3 * width * sizeof(png_byte));
 
     for (size_t y = 0; y < height; ++y) {
         row_pointers[y] = data + width * 4 * y;
     }
-    
+
     // Write the image data to file
     png_init_io   (png_ptr, fp);
     png_set_rows  (png_ptr, info_ptr, row_pointers);
     png_write_png (png_ptr, info_ptr, PNG_TRANSFORM_BGR, NULL);
 
- //   free (row_pointers); 
- //   png_destroy_write_struct (&png_ptr, &info_ptr);  
+ //   free (row_pointers);
+ //   png_destroy_write_struct (&png_ptr, &info_ptr);
     fclose (fp);
    return;
 }
@@ -917,7 +916,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon(const Polyline& line) con
 		vector<double> x;
 		vector<double> y;
 		line.hole(h,x,y);
-		if ( x.empty() ) 
+		if ( x.empty() )
 			continue;
 		cairo_move_to (cr_, projectX(x[0]),setY(projectY(y[0])));
 		vector<double>::const_iterator yt = y.begin();
@@ -1046,7 +1045,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon() const
 			cairo_move_to(cr2, density+.5*.5, 0);
 			cairo_line_to(cr2, density+.5*.5, density+.5);
 		}
-		if(indexHatch_==4 || indexHatch_==6) 
+		if(indexHatch_==4 || indexHatch_==6)
 		{
 			cairo_move_to(cr2,       0, 0);
 			cairo_line_to(cr2, density+.5, density+.5);
@@ -1102,7 +1101,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSimplePolygon() const
 
   Cairo expects a string as a char array, where each character is expressed as
   16 bit Unicode. Expat however delivers Multi-Byte encoding!
-  
+
   \sa http://www.pygtk.org/docs/pygtk/pango-markup-language.html
 
   \sa Text
@@ -1122,7 +1121,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderText(const Text& text) const
 	vector<NiceText>::const_iterator niceText = text.textBegin();
 	vector<NiceText>::const_iterator niceTextEnd = text.textEnd();
 
-	MFloat textXoffset = 0.;
+	//MFloat textXoffset = 0.;
 	ostringstream alltext;
 
 	for(;niceText<niceTextEnd;niceText++)
@@ -1321,7 +1320,7 @@ MAGICS_NO_EXPORT bool CairoDriver::renderPixmap(MFloat x0,MFloat y0,MFloat x1,MF
 	cairo_save(cr_);
 	cairo_antialias_t t = cairo_get_antialias(cr_);
 	cairo_set_antialias(cr_, CAIRO_ANTIALIAS_NONE);
-	
+
 	for(int i=h-1;i>=0;i--)
 	{
 		for(int j=0;j<w; x0+=dx,j++)
@@ -1467,7 +1466,7 @@ MAGICS_NO_EXPORT bool CairoDriver::renderCellArray(const Image& image) const
 		const float cr = lt[c].red();
 		const float cg = lt[c].green();
 		const float cb = lt[c].blue();
-		
+
 		if(cr*cg*cb <0)
 		{
 			chImage[jj]=0; jj++;
@@ -1548,7 +1547,7 @@ MAGICS_NO_EXPORT void CairoDriver::renderSymbols(const Symbol& symbol) const
 	}
 	else
 	{
-	    string logofile = getEnvVariable("MAGPLUS_HOME") + MAGPLUS_PATH_TO_SHARE_;	
+	    string logofile = getEnvVariable("MAGPLUS_HOME") + MAGPLUS_PATH_TO_SHARE_;
 		if     (symbolName == "logo_cams") logofile += "CAMS_combined.png";
 		else if(symbolName == "logo_c3s")  logofile += "C3S_combined.png";
 		else   logofile += "ecmwf_logo_2014.png";
