@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -87,9 +87,11 @@ public:
 
 private:
 	MAGICS_NO_EXPORT void startPage() const;
-        MAGICS_NO_EXPORT void endPage() const;
+    MAGICS_NO_EXPORT void endPage() const;
 	MAGICS_NO_EXPORT void project(const Layout& lay) const;
 	MAGICS_NO_EXPORT void unproject() const;
+	void newLayer(Layer&) const;
+	void closeLayer(Layer&) const;
 	MAGICS_NO_EXPORT void setupNewSurface() const;
 
 	MAGICS_NO_EXPORT void setNewLineWidth(const MFloat) const;
@@ -114,11 +116,10 @@ private:
 	void print(ostream&) const;
 	MAGICS_NO_EXPORT void debugOutput(const string &s) const;
 
-	mutable string	filename_;
-
 	mutable cairo_t*	cr_;
 	mutable cairo_t*	tmp_cr_;
 	mutable cairo_surface_t* surface_;
+	//mutable cairo_surface_t* surfaceBackground_;
 	mutable cairo_surface_t* tmp_surface_;
 
 	MAGICS_NO_EXPORT MFloat projectX(const MFloat x) const {return offsetX_+(x*coordRatioX_);}
