@@ -1567,25 +1567,44 @@ MAGICS_NO_EXPORT void QtDriver::renderImage(const ImportObject& obj) const
 	else if(magCompare(f,"svg")) return; //format = SVG;
 	else return;
 	
-	MFloat width=0;
-	MFloat height=0;
-
-	if(obj.getWidth()==-1 && ( magCompare(f,"gif") || magCompare(f,"png") || magCompare(f,"jpeg")|| magCompare(f,"jpg") ) )
-	{
-		return;
-	}
-	else
-	{
-		width  = obj.getWidth();
-		height = obj.getHeight();
-	}
+    MFloat width  = obj.getWidth(); //cm
+    MFloat height = obj.getHeight(); //cm
 
+    if(width == 0. || height == 0.)
+        return;
+    
 	QImage img(obj.getPath().c_str());
 	if(img.isNull())
 	{
 		return;
 	}
 
+	if(width < 0)
+    {    
+        width=img.width(); //pixels
+        //We need the width in cm
+        MFloat cm0=projectX(obj.getOrigin().x());
+        MFloat cm1=projectX(obj.getOrigin().x()+1.);
+        MFloat cm=fabs(cm1-cm0);
+        if(cm > 0.)
+            width/=cm;
+        else
+            return;
+    }    
+        
+    if(height < 0)
+    {
+        height=img.height(); //pixels
+        //We need the height in cm
+        MFloat cm0=projectY(obj.getOrigin().y());
+        MFloat cm1=projectY(obj.getOrigin().y()+1.);
+        MFloat cm=fabs(cm1-cm0);
+        if(cm > 0.)
+            height/=cm;
+        else
+            return;
+    }   
+    
 	MgQPixmapItem *item=new MgQPixmapItem(QPixmap::fromImage(img.mirrored(false,true)));
 	
 	MFloat x0=projectX(obj.getOrigin().x());
@@ -2428,6 +2447,7 @@ QColor QtDriver::getQtColour(const Colour &col) const
 	qreal r=col.red();
 	qreal g=col.green();
 	qreal b=col.blue();
+    qreal alpha=col.alpha();
 	
 	if(r < 0.) r=0.;
 	else if(r > 1.) r=1.;
@@ -2437,8 +2457,11 @@ QColor QtDriver::getQtColour(const Colour &col) const
 	
 	if(b < 0.) b=0.;
 	else if(b > 1.) b=1.;
-	
-	return QColor::fromRgbF(r,g,b);
+    
+    if(alpha < 0.) alpha=0.;
+	else if(alpha > 1.) alpha=1.;
+
+	return QColor::fromRgbF(r,g,b,alpha);
 }	
 		
 static SimpleObjectMaker<QtDriver, BaseDriver> Qt_driver("Qt");
