@@ -84,10 +84,13 @@ MagLog::debug() << "OBS ITEM - ObsWind - Lon/Lat: "<<point.longitude()<<" / "<<p
 	const Transformation& transformation = symbol.parent().transformation();
 	PaperPoint pp(point.longitude(), point.latitude());
 	std::pair<double, double> wind = std::make_pair(speed->second, direction->second);
-	transformation.reprojectSpeedDirection(pp, wind);
+	if ( owner_->wind_projected_ ) 
+		transformation.reprojectSpeedDirection(pp, wind);
+	
+	flag->speed(wind.first);
+	flag->direction(wind.second);
+
 	
-	flag->speed(speed->second);
-	flag->direction(direction->second);
 
 	if (point.latitude() <0 ) 
 		flag->setHemisphere(SOUTH);
@@ -184,14 +187,38 @@ void ObsCloudAndWind::operator()( CustomisedPoint& point, ComplexSymbol& symbol)
 	const Transformation& transformation = symbol.parent().transformation();
 	PaperPoint pp(point.longitude(), point.latitude());
 	std::pair<double, double> wind = std::make_pair(speed, direction);
-	transformation.reprojectSpeedDirection(pp, wind);
+	if ( owner_->wind_projected_ ) 
+		transformation.reprojectSpeedDirection(pp, wind);
+	
+	flag->speed(wind.first);
+	flag->direction(wind.second);
+
+	
+	if (point.latitude() <0 ) 
+		flag->setHemisphere(SOUTH);
+	symbol.add(flag);
+/*
+	flag = new FlagItem();
+	flag->setColour(Colour("red"));
+	flag->length(owner_->size_*2.5); // Size to be adjusted later!
+	flag->thickness(1.5);
+
+	flag->setOriginHeight(owner_->ring_size_ * 1.75);
+	flag->setOriginMarker(origin);
+	flag->x(0);
+	flag->y(0);
+	
+	
 	
 	flag->speed(speed);
 	flag->direction(direction);
 
+	
 	if (point.latitude() <0 ) 
 		flag->setHemisphere(SOUTH);
 	symbol.add(flag);
+*/
+
 }
 
 void ObsPressure::visit(std::set<string>& tokens)
